@@ -2,7 +2,7 @@
 # python2.5 /usr/lib/hildon-desktop/shutter.py
 
 APP_TITLE = "Shutter"
-APP_VERSION = "1.0"
+APP_VERSION = "1.1"
 
 import gobject
 import gtk
@@ -54,7 +54,7 @@ class ShutterHomePlugin(hildondesktop.HomePluginItem):
     self.hbox = gtk.HBox()
     self.vbox = gtk.VBox()
     self.e_eventbox = gtk.EventBox()
-    self.e_eventbox.set_size_request(48, 64) 
+    self.e_eventbox.set_size_request(64, 72) 
     self.e_eventbox.set_events(gtk.gdk.BUTTON_PRESS_MASK)
     self.e_eventbox.connect("button-release-event", self.on_toggle)
     self.hbox.pack_start(self.e_eventbox, True, True, 10)
@@ -125,10 +125,13 @@ class ShutterHomePlugin(hildondesktop.HomePluginItem):
     elif self.CAMERA == 'Olympus':
       remote = "Olympus_RM-2"   #<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<< Configure the name of your remote here (check available remotes with: irsend list "" ""
       code = "CAPTURE"    #<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<< Configure the name of your remote command here (available commands: look into the whateveryourremote.
+    elif self.CAMERA == 'Pentax':
+      remote = "Pentax_RC-F"   #<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<< Configure the name of your remote here (check available remotes with: irsend list "" ""
+      code = "CAPTURE"    #<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<< Configure the name of your remote command here (available commands: look into the whateveryourremote.
     #elif self.CAMERA == 'Sony':
     #  remote = "NikonDSLR"   #<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<< Configure the name of your remote here (check available remotes with: irsend list "" ""
     #  code = "shutter"    #<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<< Configure the name of your remote command here (available commands: look into the whateveryourremote.
-         
+          
     start = time.time()
     print "\n___" + datetime.datetime.now().strftime("%H:%M:%S") + "____________________________________"
     print "Running as User " + os.getenv("LOGNAME")
@@ -160,12 +163,15 @@ class ShutterHomePlugin(hildondesktop.HomePluginItem):
     # lircd is now started, so try and transmit
     start = time.time()
     print "Sending",remote,code 
+    
+    #Patch suggestion from Access(jfors). Unused here, as I fixed something in the postinstall instead (lirc restart instead of reload)
+    #irsend = subprocess.Popen(('/usr/bin/irsend', '-a', 'localhost:8765', 'send_once', remote, code),
     irsend = subprocess.Popen(('/usr/bin/irsend', 'send_once', remote, code),
                               stdin = subprocess.PIPE)
     irsend.stdin.close()
     irsend.wait()
     if irsend.returncode != 0:
-        message = "IRsend failed: %d" % irsend.returncode
+        message = "IRsend failed: %d (Please reboot and try again)" % irsend.returncode
     else:
         message = "IRsend took %d seconds (%s:%s)" %( (time.time() - start) , remote, code)
     print message
@@ -251,6 +257,9 @@ class ShutterHomePlugin(hildondesktop.HomePluginItem):
       btnOlympus = hildon.GtkRadioButton(gtk.HILDON_SIZE_HALFSCREEN_WIDTH | gtk.HILDON_SIZE_FINGER_HEIGHT, btnNikon)
       btnOlympus.set_label("Olympus")
       btnOlympus.set_mode(False)
+      btnPentax = hildon.GtkRadioButton(gtk.HILDON_SIZE_HALFSCREEN_WIDTH | gtk.HILDON_SIZE_FINGER_HEIGHT, btnNikon)
+      btnPentax.set_label("Pentax")
+      btnPentax.set_mode(False)
       #btnSony = hildon.GtkRadioButton(gtk.HILDON_SIZE_HALFSCREEN_WIDTH | gtk.HILDON_SIZE_FINGER_HEIGHT, btnNikon)
       #btnSony.set_label("Sony")
       #btnSony.set_mode(False)
@@ -261,6 +270,8 @@ class ShutterHomePlugin(hildondesktop.HomePluginItem):
          btnCanon.set_active(True)
       elif self.CAMERA == 'Olympus':
          btnOlympus.set_active(True)
+      elif self.CAMERA == 'Pentax':
+         btnPentax.set_active(True)
       #elif self.CAMERA == 'Sony':
       #   btnSony.set_active(True)
       else:
@@ -270,6 +281,7 @@ class ShutterHomePlugin(hildondesktop.HomePluginItem):
       hBoxLayout.pack_start(btnCanon, True, True, 0)
       hBoxLayout.pack_start(btnNikon, True, True, 0)
       hBoxLayout.pack_start(btnOlympus, True, True, 0)
+      hBoxLayout.pack_start(btnPentax, True, True, 0)
       #hBoxLayout.pack_end(btnSony, True, True, 0)
       main_vbox.pack_start(hBoxLayout, True, True, 10)
 
